@@ -14,13 +14,9 @@ fn main() -> Result<(), Box<dyn Error>> {
 
     let kernel = HierarchicalCluster::default()
         .num_clusters(3)
-        .transform(kernel);
+        .transform(kernel)?;
 
-    for (id, target) in kernel
-        .targets()
-        .into_iter()
-        .zip(dataset.targets().into_iter())
-    {
+    for (id, target) in kernel.targets().iter().zip(dataset.targets().into_iter()) {
         let name = match *target as usize {
             0 => "setosa",
             1 => "versicolor",
@@ -30,7 +26,7 @@ fn main() -> Result<(), Box<dyn Error>> {
 
         print!("({} {}) ", id, name);
     }
-    println!("");
+    println!();
 
     Ok(())
 }
